package fr.itsee.season;

import android.content.Context;
import android.graphics.Color;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.TextView;

import java.util.ArrayList;
import java.util.List;

public class ColisAdapter extends RecyclerView.Adapter<ColisAdapter.MyViewHolder> {

    private ColisAdapter.OnItemClickListener mListener;
    private List<Colis> listeColis;
    private final Context context;

    public interface OnItemClickListener {
        void onSupprClick(int position);
    }

    public void setOnItemClickListener(ColisAdapter.OnItemClickListener listener){
        mListener = listener;
    }

    public class MyViewHolder extends RecyclerView.ViewHolder{
        public TextView numeroCommande, codeColis, numeroColis, nomClient;
        public Button suppr;

        public MyViewHolder(View view, final ColisAdapter.OnItemClickListener listener) {
            super(view);
            numeroCommande = view.findViewById(R.id.numeroCommande);
            codeColis = view.findViewById(R.id.codeColis);
            numeroColis = view.findViewById(R.id.numeroColis);
            nomClient = view.findViewById(R.id.nomClient);
            suppr = view.findViewById(R.id.suppr);

            suppr.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null){
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION){
                            listener.onSupprClick(position);
                        }
                    }
                }
            });
        }
    }


    public ColisAdapter(ArrayList<Colis> listeColis, Context context) {
        this.listeColis = listeColis;
        this.context = context;
    }

    public void setListeColis(List<Colis> listeColis) {
        this.listeColis = listeColis;
    }

    @Override
    public MyViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View itemView = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.ligne_colis, parent, false);

        return new MyViewHolder(itemView, mListener);
    }



    @Override
    public void onBindViewHolder(final MyViewHolder holder, final int position) {
        final Colis c = listeColis.get(position);

        holder.numeroCommande.setText(""+c.getNumeroCommande());
        holder.codeColis.setText(""+c.getCodeColis());
        holder.numeroColis.setText(""+c.getNumeroColis()+" / "+c.getQuantite_colis());

        if (c.getNomClient() != "" && c.getNomClient() != "null" && c.getNomClient() != null) {
            holder.nomClient.setText("" + c.getNomClient());
        } else {
            holder.nomClient.setText("Invité");
        }
        if (c.getPret() == 1){
            holder.itemView.setBackgroundColor(Color.GREEN);
        }else {
            holder.itemView.setBackgroundColor(Color.TRANSPARENT);
        }

    }

    @Override
    public int getItemCount() {
        return listeColis.size();
    }

}