package fr.itsee.season;

import android.app.Activity;
import android.content.Intent;
import android.icu.text.DecimalFormat;
import android.os.AsyncTask;
import android.os.Parcelable;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.GridLayout;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.squareup.picasso.Picasso;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class FicheProduitActivity extends AppCompatActivity {


    private List<Produit> listProduitRef;
    private List<Integer> listeImageIndex;
    private GridLayout grilleCouleurs;
    private TextView ref, coloris, prix, infos;
    private ImageView selectedImage;
    private Button ajouter;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_fiche_produit);

        DecimalFormat df = new DecimalFormat("0.00");

        grilleCouleurs = findViewById(R.id.couleur);
        ref = findViewById(R.id.ref);
        coloris = findViewById(R.id.coloris);
        prix = findViewById(R.id.prix);
        infos = findViewById(R.id.infos);
        ajouter = findViewById(R.id.ajouter);

        Intent intent = getIntent();
        Produit p = intent.getParcelableExtra("produit");

        ref.setText(p.getRef());
        coloris.setText(p.getColoris());
        prix.setText(df.format(p.getPrix()) + "€ HT");
        infos.setText(p.getInformations());

        listProduitRef = new ArrayList<>();
        listeImageIndex = new ArrayList<>();

        for (Produit produit : CommandesActivity.listeAllProduits){
            if (produit.getRef().equals(p.getRef())){
                listProduitRef.add(produit);
                listeImageIndex.add(CommandesActivity.listeAllProduits.indexOf(produit));
            }
        }

        LinearLayout.LayoutParams lp = new LinearLayout.LayoutParams(LinearLayout.LayoutParams.WRAP_CONTENT, LinearLayout.LayoutParams.WRAP_CONTENT);
        lp.setMargins(5, 5, 5, 5);

        int i = 0;
        for(Produit pr : listProduitRef){
            ImageView image = new ImageView(getApplicationContext());
            if (!pr.getLien_image().equals("")){
                String imageURL = MainActivity.backOfficeURLIMG+pr.getLien_image();
                Picasso.with(getApplicationContext()).load(imageURL).into(image);
            }else{
                image.setImageResource(R.drawable.image_not_found);
            }

            image.setLayoutParams(lp);
            image.setId(i);
            if (pr.getColoris().equals(p.getColoris())){
                selectedImage = image;
                image.setBackground(getDrawable(R.drawable.selected_color));

                int qte = 0;
                try {
                    qte = CommandesActivity.getProduitInCommande(pr.getCode128()).getQte();
                }catch (Exception e){
                }

                if (pr != null){
                    if (pr.getStock() - qte <= -1){
                        ajouter.setEnabled(false);
                        ajouter.setBackground(getDrawable(R.drawable.button_style_disable));
                    }else{
                        ajouter.setEnabled(true);
                        ajouter.setBackground(getDrawable(R.drawable.button_style_valider));
                    }
                }else{
                    ajouter.setEnabled(true);
                    ajouter.setBackground(getDrawable(R.drawable.button_style_valider));
                }
            }
            else{
                image.setBackground(getDrawable(R.drawable.unselected_color));
            }

            grilleCouleurs.addView(image, 0);
            image.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    selectedImage.setBackground(getDrawable(R.drawable.unselected_color));
                    selectedImage = ((ImageView)view);
                    selectedImage.setBackground(getDrawable(R.drawable.selected_color));

                    Produit p = listProduitRef.get(selectedImage.getId());
                    new RefreshProduitAsyncTask().execute(p);

                    ref.setText(p.getRef());
                    coloris.setText(p.getColoris());
                    DecimalFormat df = new DecimalFormat("0.00");
                    prix.setText(df.format(p.getPrix()) + " € HT");
                    infos.setText(p.getInformations());


                }
            });
            i += 1;

            image.getLayoutParams().height = 130;
            image.getLayoutParams().width = 100;
        }
    }


    public void ajouter(View v){
        Intent returnIntent = new Intent();
        returnIntent.putExtra("produit", listProduitRef.get(selectedImage.getId()));
        setResult(Activity.RESULT_OK,returnIntent);
        finish();
    }

    public void annuler(View v){
        Intent returnIntent = new Intent();
        setResult(Activity.RESULT_CANCELED, returnIntent);
        finish();
    }

    private class RefreshProduitAsyncTask extends AsyncTask<Produit, String, String> {

        //BASE DE DONNEES
        private final String BASE_URL = MainActivity.backOfficeURL;

        private Produit p;
        private int success;

        @Override
        protected String doInBackground(Produit... produits) {
            p = produits[0];

            HttpJsonParser httpJsonParser2 = new HttpJsonParser();
            Map<String, String> httpParams2 = new HashMap<>();

            httpParams2.put("code_128", p.getCode128());
            JSONObject jsonObject2 = httpJsonParser2.makeHttpRequest(
                    BASE_URL + "getStockProduit.php", "GET", httpParams2);

            try {
                success = jsonObject2.getInt("success");
                if (success == 1){
                    JSONObject produit = jsonObject2.getJSONArray("data").getJSONObject(0);
                    if (produit.getString("stock") == "null" || produit.getString("stock") == null) {
                        p.setStock(0);
                    } else {
                        p.setStock(Integer.parseInt(produit.getString("stock")));
                    }
                }

            } catch (JSONException e) {
                e.printStackTrace();
            }

            return null;
        }

        @Override
        protected void onPostExecute(String s) {
            super.onPostExecute(s);
            int qte = 0;
            try {
                p = CommandesActivity.getProduitInListeProduit(p.getCode128());
                qte = p.getQte();
                if ((p.getStock() != 0) && p.getStock() - qte - 1 <= -1){
                    ajouter.setEnabled(false);
                    ajouter.setBackground(getDrawable(R.drawable.button_style_disable));
                }else{
                    ajouter.setEnabled(true);
                    ajouter.setBackground(getDrawable(R.drawable.button_style_valider));
                }
            }catch (Exception e){
            }
        }
    }
}
