package fr.itsee.season;

import android.content.Context;
import android.graphics.Color;
import android.icu.text.DecimalFormat;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.squareup.picasso.Picasso;

import java.util.ArrayList;
import java.util.List;

public class ProduitAdapterControle extends RecyclerView.Adapter<ProduitAdapterControle.MyViewHolder> {

    private List<Produit> listeProduit;
    private final Context context;

    public class MyViewHolder extends RecyclerView.ViewHolder{
        public TextView ref, rayon, stock, coloris, qte, prixTotale, nbrScanner;
        public ImageView photo;


        public MyViewHolder(View view) {
            super(view);
            ref = view.findViewById(R.id.ref);
            rayon = view.findViewById(R.id.rayon);
            coloris = view.findViewById(R.id.coloris);
            qte = view.findViewById(R.id.qte);
            prixTotale = view.findViewById(R.id.prixTotale);
            photo = view.findViewById(R.id.photo);
            nbrScanner = view.findViewById(R.id.nbrScanner);
        }
    }


    public ProduitAdapterControle(ArrayList<Produit> listeProduit, Context context) {
        this.listeProduit = listeProduit;
        this.context = context;
    }

    public void setListeProduit(List<Produit> listeProduit) {
        this.listeProduit = listeProduit;
    }

    @Override
    public MyViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View itemView = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.ligne_produit_controle, parent, false);

        return new MyViewHolder(itemView);
    }



    @Override
    public void onBindViewHolder(final MyViewHolder holder, final int position) {
        DecimalFormat df = new DecimalFormat("0.00");
        final Produit p = listeProduit.get(position);

        holder.ref.setText(p.getRef());
        if (p.getNumero_de_rayon() != "") {
            holder.rayon.setText("Num rayon: " + p.getNumero_de_rayon());
        } else {
            holder.rayon.setText("");
        }
        holder.coloris.setText(p.getColoris());
        holder.qte.setText("Qté: " + p.getQte() + " x " + p.getQuantite_pack() + "pcs");
        holder.prixTotale.setText(""+df.format(p.getPrixTotale())+"€");
        if (!p.getLien_image().equals("")){
            String imageURL = MainActivity.backOfficeURLIMG+p.getLien_image();
            Picasso.with(this.context).load(imageURL).into(holder.photo);
        }else{
            holder.photo.setImageResource(R.drawable.image_not_found);
        }

        holder.nbrScanner.setText(p.getNbrScanner() + "/" + p.getQte());

        if (p.getNbrScanner() == p.getQte()){
            holder.itemView.setBackgroundColor(Color.GREEN);
        }else if (p.getNbrScanner() > p.getQte()){
            holder.itemView.setBackgroundColor(Color.RED);
        }else if (ControleActivity.dernierePosition == position) {
            holder.itemView.setBackgroundColor(Color.parseColor("#F0F0F0")); //GRIS CLAIR LIGNE EN COURS D'EDITION
        } else {
            holder.itemView.setBackgroundColor(Color.parseColor("#FFFFFF")); //BLANC
        }

    }

    @Override
    public int getItemCount() {
        return listeProduit.size();
    }

}