package fr.itsee.season;

import android.content.Context;
import android.icu.text.DecimalFormat;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.squareup.picasso.Picasso;

import java.util.ArrayList;
import java.util.List;

public class ProduitAdapterRecherche extends RecyclerView.Adapter<ProduitAdapterRecherche.MyViewHolder> {

    private List<Produit> listeAllProduit;
    private OnItemClickListener mListener;
    private final Context context;

    public interface OnItemClickListener {
        void onClik(int position);

    }

    public void setOnItemClickListener(OnItemClickListener listener){
        mListener = listener;
    }
    public class MyViewHolder extends RecyclerView.ViewHolder{
        public TextView ref, prix, coloris, qte, prixTotale;
        public ImageView photo;


        public MyViewHolder(View view, final OnItemClickListener listener) {
            super(view);
            ref = view.findViewById(R.id.ref);
            prix = view.findViewById(R.id.prix);
            coloris = view.findViewById(R.id.coloris);
            qte = view.findViewById(R.id.qte);
            prixTotale = view.findViewById(R.id.prixTotale);
            photo = view.findViewById(R.id.photo);

            view.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null){
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION){
                            listener.onClik(position);
                        }
                    }
                }
            });
        }
    }

    public ProduitAdapterRecherche(ArrayList<Produit> listeAllProduit, Context context) {
        this.listeAllProduit = listeAllProduit;
        this.context = context;
    }

    public void setListeAllProduit(List<Produit> listeAllProduit) {
        this.listeAllProduit = listeAllProduit;
    }

    @Override
    public MyViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View itemView = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.ligne_produit_recherche, parent, false);
        return new MyViewHolder(itemView, mListener);
    }

    @Override
    public void onBindViewHolder(final MyViewHolder holder, final int position) {
        DecimalFormat df = new DecimalFormat("0.00");
        final Produit p = listeAllProduit.get(position);
        holder.ref.setText(p.getRef());
        holder.prix.setText("Prix: " + df.format(p.getPrix())+"€");
        holder.coloris.setText(p.getColoris());
        holder.qte.setText("Qté: " + p.getQte() + " x " + p.getQuantite_pack() + "pcs");
        holder.prixTotale.setText(""+df.format(p.getPrixTotale())+"€");
        if (!p.getLien_image().equals("")){
            String imageURL = MainActivity.backOfficeURLIMG+p.getLien_image();
            Picasso.with(this.context).load(imageURL).into(holder.photo);
        }else{
            holder.photo.setImageResource(R.drawable.image_not_found);
        }
    }

    @Override
    public int getItemCount() {
        return listeAllProduit.size();
    }

}