package fr.itsee.season;

import android.content.Context;
import android.graphics.Color;
import android.icu.text.DecimalFormat;
import android.os.StrictMode;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.squareup.picasso.Picasso;

public class ProduitAdapterReglement extends RecyclerView.Adapter<ProduitAdapterReglement.MyViewHolder> {

    private Commande cmd;
    private OnItemClickListener mListener;
    private final Context context;

    public interface OnItemClickListener {
        void onPhotoClik(int position);
        void onSupprClick(int position);
        void onPlusClick(int position);
        void onMoinsClick(int position);
        void onQuantiteClick(int position);
    }

    public void setOnItemClickListener(OnItemClickListener listener){
        mListener = listener;
    }

    public class MyViewHolder extends RecyclerView.ViewHolder{
        public TextView ref, prix, coloris, qte, prixTotale;
        public Button moins, plus, suppr;
        public ImageView photo;
        public LinearLayout editQte;


        public MyViewHolder(View view, final OnItemClickListener listener) {
            super(view);

            StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
            StrictMode.setThreadPolicy(policy);

            ref = view.findViewById(R.id.ref);
            prix = view.findViewById(R.id.prix);
            coloris = view.findViewById(R.id.coloris);
            qte = view.findViewById(R.id.qte);
            prixTotale = view.findViewById(R.id.prixTotale);
            moins = view.findViewById(R.id.moins);
            plus = view.findViewById(R.id.plus);
            suppr = view.findViewById(R.id.suppr);
            photo = view.findViewById(R.id.photo);
            editQte = view.findViewById(R.id.changeQte);

            suppr.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null){
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION){
                            listener.onSupprClick(position);
                        }
                    }
                }
            });

            plus.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null){
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION){
                            listener.onPlusClick(position);
                        }
                    }
                }
            });

            moins.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null){
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION){
                            listener.onMoinsClick(position);
                        }
                    }
                }
            });

            photo.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null){
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION){
                            listener.onPhotoClik(position);
                        }
                    }
                }
            });

            ref.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null){
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION){
                            listener.onQuantiteClick(position);
                        }
                    }
                }
            });
            coloris.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null){
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION){
                            listener.onQuantiteClick(position);
                        }
                    }
                }
            });
            qte.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null){
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION){
                            listener.onQuantiteClick(position);
                        }
                    }
                }
            });
            editQte.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    if (listener != null){
                        int position = getAdapterPosition();
                        if (position != RecyclerView.NO_POSITION){
                            listener.onQuantiteClick(position);
                        }
                    }
                }
            });
        }
    }


    public ProduitAdapterReglement(Commande cmd, Context context) {
        this.cmd = cmd;
        this.context = context;
    }

    public Commande getCmd() {
        return cmd;
    }

    public void setCmd(Commande cmd) {
        this.cmd = cmd;
    }

    @Override
    public MyViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View itemView = LayoutInflater.from(parent.getContext())
                .inflate(R.layout.ligne_produit_reglement, parent, false);
        return new MyViewHolder(itemView, mListener);
    }

    @Override
    public void onBindViewHolder(final MyViewHolder holder, final int position) {
        DecimalFormat df = new DecimalFormat("0.00");
        final Produit p = cmd.getListeProduit().get(position);
        holder.ref.setText(p.getRef());
        holder.prix.setText("Prix: " + df.format(p.getPrix())+"€");
        holder.coloris.setText(p.getColoris());
        holder.qte.setText("Qté: " + p.getQte() + " x " + p.getQuantite_pack() + "pcs");
        if(p.getStock() - p.getQte() < -1){
            holder.qte.setTextColor(Color.RED);
        }else{
            holder.qte.setTextColor(Color.GRAY);
        }
        holder.prixTotale.setText(""+df.format(p.getPrixTotale())+"€");

        if (!p.getLien_image().equals("")){
            String imageURL = MainActivity.backOfficeURLIMG+p.getLien_image();
            Picasso.with(this.context).load(imageURL).into(holder.photo);
        }else{
            holder.photo.setImageResource(R.drawable.image_not_found);
        }
        if (ReglementActivity.dernierePosition == position) {
            holder.itemView.setBackgroundColor(Color.parseColor("#F0F0F0")); //GRIS CLAIR LIGNE EN COURS D'EDITION
        } else {
            holder.itemView.setBackgroundColor(Color.parseColor("#FFFFFF")); //BLANC
        }
    }

    @Override
    public int getItemCount() {
        return cmd.getListeProduit().size();
    }
}