package fr.itsee.season;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.icu.text.DecimalFormat;
import android.os.AsyncTask;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;
import java.util.regex.Pattern;

public class ReglementPopupActivity extends AppCompatActivity {

    private EditText email, telephone;
    private Button valider, annuler;
    private TextView prixTotalHt, livraisonTotalHt, prixTotalTtc;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_reglement_popup);

        DecimalFormat df = new DecimalFormat("0.00");

        valider = findViewById(R.id.valider);
        annuler = findViewById(R.id.annuler);

        email = findViewById(R.id.emailTxt);
        telephone = findViewById(R.id.smsTxt);

        if (ReglementActivity.currentCommande != null) {
            email.setText(ReglementActivity.currentCommande.getEmailClient());
            telephone.setText(ReglementActivity.currentCommande.getTelephoneClient());
        }
        prixTotalHt = findViewById(R.id.prixTotalHt);
        livraisonTotalHt = findViewById(R.id.livraisonTotalHt);
        prixTotalTtc = findViewById(R.id.prixTotalTtc);

        Intent intent = getIntent();
        Commande cmd = intent.getParcelableExtra("commande");

        prixTotalHt.setText("Total HT: "+df.format(cmd.getPrixTotal()+cmd.getPrixLivraison())+"€");
        livraisonTotalHt.setText("Port: "+df.format(cmd.getPrixLivraison())+"€");
        prixTotalTtc.setText("Total TTC: "+df.format((cmd.getPrixTotal()+cmd.getPrixLivraison())*1.2)+"€");
    }


    public void envoyer(View v){
        if (email.getText().toString().equals("") && telephone.getText().toString().equals("")) {
            AlertDialog.Builder alertDialog = new AlertDialog.Builder(ReglementPopupActivity.this);
            alertDialog.setTitle("Règlement");
            alertDialog.setMessage("Veuillez saisir au minimum une adresse email ou un numéro de téléphone!");
            alertDialog.setPositiveButton("OK", new DialogInterface.OnClickListener() {
                public void onClick(DialogInterface dialog, int whichButton) {
                    dialog.dismiss();
                }
            });
            alertDialog.show();
        } else if (!isValidEmail(email.getText().toString()) && !email.getText().toString().equals("")) {
            AlertDialog.Builder alertDialog = new AlertDialog.Builder(ReglementPopupActivity.this);
            alertDialog.setTitle("Règlement");
            alertDialog.setMessage("Veuillez vérifier votre adresse email!");
            alertDialog.setPositiveButton("OK", new DialogInterface.OnClickListener() {
                public void onClick(DialogInterface dialog, int whichButton) {
                    dialog.dismiss();
                }
            });
            alertDialog.show();
        } else {
            if (ReglementActivity.currentCommande != null) {
                ReglementActivity.currentCommande.setEmailClient(email.getText().toString());
                ReglementActivity.currentCommande.setTelephoneClient(telephone.getText().toString());
            }
            new EnvoyerLienPaiementAsyncTask().execute();
        }
        //Fermeture de la fenêtre après envoi
    }

    private boolean isValidEmail(String email){

        return Pattern.compile("^(([\\w-]+\\.)+[\\w-]+|([a-zA-Z]{1}|[\\w-]{2,}))@"
                + "((([0-1]?[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\.([0-1]?"
                + "[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\."
                + "([0-1]?[0-9]{1,2}|25[0-5]|2[0-4][0-9])\\.([0-1]?"
                + "[0-9]{1,2}|25[0-5]|2[0-4][0-9])){1}|"
                + "([a-zA-Z]+[\\w-]+\\.)+[a-zA-Z]{2,4})$").matcher(email).matches();
    }

    public void annuler(View v){
        Intent returnIntent = new Intent();
        setResult(Activity.RESULT_CANCELED, returnIntent);
        finish();
    }

    private class EnvoyerLienPaiementAsyncTask extends AsyncTask<String, String, String> {

        //BASE DE DONNEES
        private final String BASE_URL = MainActivity.backOfficeURL;

        private Commande cmd;
        private int success;

        @Override
        protected String doInBackground(String... params) {
            cmd = ReglementActivity.currentCommande;

            HttpJsonParser httpJsonParser = new HttpJsonParser();
            Map<String, String> httpParams = new HashMap<>();

            httpParams.put("numero_commande", cmd.getNum());
            httpParams.put("montant_total_ttc", ""+(cmd.getPrixTotal()+cmd.getPrixLivraison())*1.2);
            httpParams.put("email_client", ""+cmd.getEmailClient());
            httpParams.put("telephone_client", ""+cmd.getTelephoneClient());
            JSONObject jsonObject = httpJsonParser.makeHttpRequest(
                    BASE_URL + "envoyerLienPaiement.php", "GET", httpParams);

            try {
                success = jsonObject.getInt("success");
                if (success == 1){
                    return "ok";
                }

            } catch (JSONException e) {
                e.printStackTrace();
            }

            return null;
        }

        @Override
        protected void onPostExecute(String s) {
            super.onPostExecute(s);

            ReglementActivity.currentCommande.setTelephoneClient(telephone.getText().toString());
            ReglementActivity.currentCommande.setEmailClient(email.getText().toString());

            if (s == "ok") {
                //Retour à la page règlement
                Intent returnIntent = new Intent();
                setResult(Activity.RESULT_OK, returnIntent);
                finish();
            } else {
                Toast.makeText(ReglementPopupActivity.this, "Lien non envoyé! Veuillez recommencer.", Toast.LENGTH_SHORT);
            }

        }
    }
}
